Class: Sprinkle::Installers::FreebsdPortinstall
- Defined in:
- lib/sprinkle/installers/freebsd_portinstall.rb
Overview
FreeBSD Portinstall Installer
The Portinstall installer installs FreeBSD ports.
It uses the ports-mgmt/portupgrade port to install.
Before usage, the ports system must be installed and
read on the target operating system.
It is recommended to use portsnap fetch extract to
install the ports system.
Example Usage
Installing the magic_beans port.
package :magic_beans do
freebsd_portinstall 'magic/magic_beans'
end
Instance Attribute Summary collapse
-
#port ⇒ Object
:nodoc:.
Attributes inherited from Installer
#delivery, #options, #package, #post, #pre
Attributes included from Configurable
Instance Method Summary collapse
-
#initialize(parent, port, &block) ⇒ FreebsdPortinstall
constructor
:nodoc:.
Methods inherited from Installer
Methods included from Configurable
#assert_delivery, #defaults, #method_missing, #option?
Constructor Details
#initialize(parent, port, &block) ⇒ FreebsdPortinstall
:nodoc:
23 24 25 26 |
# File 'lib/sprinkle/installers/freebsd_portinstall.rb', line 23 def initialize(parent, port, &block) #:nodoc: super parent, &block @port = port end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Sprinkle::Configurable
Instance Attribute Details
#port ⇒ Object
:nodoc:
21 22 23 |
# File 'lib/sprinkle/installers/freebsd_portinstall.rb', line 21 def port @port end |